import { select, csv } from 'd3';
import { multiBarplot } from './multiBarplot';

const csvUrl = [
  "https://raw.githubusercontent.com/", 
  "holtzy/D3-graph-gallery/", 
  "master/DATA/",
  "data_stacked.csv",
].join('');

const width = innerWidth;
const height = innerHeight;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const margin = {
  top: 20,
  right: 20,
  bottom: 40,
  left: 40,
};

const parseRow = (data) => {
  const d = {};
	d.group = data.group;
  d.Nitrogen = +data.Nitrogen;
  d.normal = +data.normal;
  d.stress = +data.stress;
  return d;
};

const main = async () => {
  let data = await csv(csvUrl, parseRow);
  
	const groups = data.map(d => d.group); // ['banana', 'poacee', 'sorgho', 'triticum']
  const subgroups = data.columns.slice(1); // ['Nitrogen', 'normal', 'stress']
  
	const plot = multiBarplot()
  	.width(width)
  	.height(height)
  	.data(data)
  	.groups(groups) // this will be in X-Axis
  	.subgroups(subgroups)
  	.margin(margin)
  
  svg.call(plot); // pass selection to the barplot
};

main();