import {
  selectAll,
  scaleBand,
  scaleLinear,
  scaleOrdinal,
  axisBottom,
  axisLeft,
} from 'd3';

export const multiBarplot = () => {
  // Dimentions
  let width = 960;
  let height = 500;
  let data = [];
  let margin = {
    top: 20,
    right: 20,
    bottom: 20,
    left: 20,
  };
  let groups = [];
  let subgroups = [];
  let colors = [
    '#37A2EB',
    '#FF6384',
    '#4CC0C0',
    '#FF9E40',
    '#9A66FF',
    '#FFCD56',
    '#C9CBCF',
  ];

  // multibar plot
  const my = (selection) => {
    // X-axis
    const xScale = scaleBand()
      .domain(groups)
      .range([margin.left, width - margin.right])
    	.padding([0.2]);
    
    selection
      .selectAll('.x-axis')
      .data([null])
      .join('g')
      .attr('class', '.x-axis')
      .attr(
        'transform',
        `translate(0, ${height - margin.bottom})`
      )
      .call(axisBottom(xScale));
    
    // X-Subgroup 
    const xSubgroup = scaleBand()
    	.domain(subgroups)
    	.range([0, xScale.bandwidth()])
    	.padding([0.05])
    
    // Colors
    const color = scaleOrdinal()
    	.domain(subgroups)
    	.range(colors)

    // Y-axis
    const yScale = scaleLinear()
    	.domain([0, 40])
    	.range([height - margin.bottom, margin.top]);
    
    selection
    	.selectAll('.y-axis')
    	.data([null])
    	.join('g')
    	.attr('class', '.x-axis')
    	.attr(
      	'transform',
      	`translate(${margin.left}, ${0})`
    	)
    	.call(axisLeft(yScale))
    
    // console.log(data)
    
    const marks = data.map(d => ({
      group: xScale(d.group),
    	x: xScale(),
    }))
    
    // console.log(data.map(d => xScale(d.group)))
    
    const x = data.map(d => subgroups.map(key => ({ key, value: d[key] })))
    
    console.log(x)

    // MultiBars
    const bars = selection
    	.selectAll('rect')
    	.data(data)
    	.join('g')
    		.attr('transform', d => `translate(${xScale(d.group)}, ${-margin.bottom})`)
    	.selectAll('rect') 
    	.data((d) => subgroups.map((key) => ({ key, value: d[key] })))
    	.join('rect')
    		.attr("x", d => xSubgroup(d.key))
      	.attr("y", d => yScale(d.value))
      	.attr("width", xSubgroup.bandwidth())
      	.attr("height", d => height - yScale(d.value))
      	.attr("fill", d => color(d.key));
  };

  // Getters & Setters
  my.width = function (_) {
    return arguments.length
      ? ((width = +_), my)
      : width;
  };
  my.height = function (_) {
    return arguments.length
      ? ((height = +_), my)
      : height;
  };
  my.data = function (_) {
    return arguments.length
      ? ((data = _), my)
      : data;
  };
  my.groups = function (_) {
    return arguments.length
      ? ((groups = _), my)
      : groups;
  };
  my.subgroups = function (_) {
    return arguments.length
      ? ((subgroups = _), my)
      : subgroups;
  };
  my.margin = function (_) {
    return arguments.length
      ? ((margin = _), my)
      : margin;
  };

  return my;
};
